@@ -6,22 +6,32 @@ All configurations for pymultigit
 from pytconf import Config, ParamCreator
 
 
+class ConfigOutput(Config):
+    """
+    Parameters to control output
+    """
+    terse = ParamCreator.create_bool(
+        help_string="be terse?",
+        default=False,
+    )
+    stats = ParamCreator.create_bool(
+        help_string="show statistics are the end?",
+        default=False,
+    )
+
+
 class ConfigDebug(Config):
     """
     Parameters for debug
     """
     verbose = ParamCreator.create_bool(
         help_string="be verbose?",
-        default=True,
+        default=False,
     )
     git_verbose = ParamCreator.create_bool(
         help_string="add --verbose when running git?",
         default=False,
     )
-    terse = ParamCreator.create_bool(
-        help_string="be terse?",
-        default=False,
-    )
     quiet = ParamCreator.create_bool(
         help_string="be quiet?",
         default=False,
@@ -30,10 +40,6 @@ class ConfigDebug(Config):
         help_string="add --quiet when running git?",
         default=False,
     )
-    stats = ParamCreator.create_bool(
-        help_string="show statistics are the end?",
-        default=False,
-    )
 
 
 class ConfigMain(Config):
