@@ -7,7 +7,7 @@ from typing import Tuple, Generator
 
 import git
 
-from pymultigit.configs import ConfigDebug, ConfigGrep, ConfigPull, ConfigMain
+from pymultigit.configs import ConfigOutput, ConfigDebug, ConfigGrep, ConfigPull, ConfigMain
 
 
 def projects(sort: bool) -> Generator[Tuple[str, str], None, None]:
@@ -38,7 +38,7 @@ def run(args, do_exit=True) -> Tuple[str, str, int]:
     return res_out, res_err, p.returncode
 
 
-def do_count(fnc, attr_name, not_attr_name, attr_plural) -> None:
+def do_count(fnc, attr_name, not_attr_name, attr_plural, print_attr, print_not_attr) -> None:
     count = 0
     count_attr = 0
     for (project_name, project_dir) in projects(sort=ConfigMain.sort):
@@ -47,12 +47,19 @@ def do_count(fnc, attr_name, not_attr_name, attr_plural) -> None:
         attr = fnc(repo)
         if attr:
             count_attr += 1
-        if ConfigDebug.verbose:
-            if attr:
-                print(f'project [{project_name}] {attr_name}')
-            else:
-                print(f'project [{project_name}] {not_attr_name}')
-    if ConfigDebug.stats:
+        if attr:
+            if print_attr:
+                if ConfigOutput.terse:
+                    print(project_name)
+                else:
+                    print(f'project [{project_name}] {attr_name}')
+        else:
+            if print_not_attr:
+                if ConfigOutput.terse:
+                    print(project_name)
+                else:
+                    print(f'project [{project_name}] {not_attr_name}')
+    if ConfigOutput.stats:
         print(f'scanned [{count}] projects')
         print(f'[{count_attr}] projects {attr_plural}')
 
@@ -82,7 +89,7 @@ def do_for_all_projects(fnc) -> None:
             if ConfigDebug.verbose:
                 print('NOT FOUND')
             count_not_found += 1
-    if ConfigDebug.stats:
+    if ConfigOutput.stats:
         print(f'scanned [{count}] projects')
         print(f'[{count_not_found}] not found')
         print(f'[{count_error}] error')
@@ -108,7 +115,7 @@ def do_build(_project_name: str, project_dir: str) -> None:
         pass
     if os.path.isfile(bootstrap):
         pass
-    if ConfigDebug.stats:
+    if ConfigOutput.stats:
         pass
 
 
@@ -203,7 +210,7 @@ def do_status_msg(project_name: str, msg: str) -> int:
         '@...@{upstream}',
     ])
     if res_out != '0\n' or res_err != '':
-        if ConfigDebug.terse:
+        if ConfigOutput.terse:
             msg = project_name
         else:
             msg = f'project [{project_name}] is not synced'
@@ -216,15 +223,19 @@ def do_status_msg(project_name: str, msg: str) -> int:
 
 
 def do_status(project_name: str, _project_dir: str) -> int:
-    if ConfigDebug.terse:
+    if ConfigOutput.terse:
         msg = f"{project_name}"
     else:
         msg = f"project [{project_name}] is dirty"
     return do_status_msg(project_name=project_name, msg=msg)
 
 
-def do_dirty(project_name: str, _project_dir: str) -> int:
-    return do_status_msg(project_name=project_name, msg=f'{project_name}')
+def do_dirty(project_name: str, project_dir: str) -> int:
+    if ConfigOutput.terse:
+        msg = project_name
+    else:
+        msg = f"project [{project_name}] at directory [{project_dir}]"
+    return do_status_msg(project_name=project_name, msg=msg)
 
 
 def do_print(project_name: str, project_dir: str) -> None:
